# Exporting Fact Sheet Data as Excel File
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file#introduction)
  * [Exporting Fact Sheet Data as an Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file#exporting-fact-sheet-data-as-an-excel-file)
  * [Creating a Template for Import](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file#creating-a-template-for-import)


SAP LeanIX’s export feature allows you to export fact sheet data as an Excel file for bulk updates, easy data manipulation, and offline analysis. The exported file also serves as a template for importing data back into SAP LeanIX.
